# -*- encoding : utf-8 -*-
class FrontPageLock < ActiveRecord::Base
  BANNER_ID = 0

  belongs_to :event

  validates :position, presence: true, uniqueness: true

  validates :event_id, uniqueness: true, if: :event_id?
  validate :event_revealed_and_upcoming, if: :event_id?

  attr_accessible :event_id, :position

  scope :locks_enabled, -> {
    where('event_id IS NOT null')
    .order(:position)}

  def event_revealed_and_upcoming
    unless event.try(:revealed_and_upcoming?)
      errors.add(:event_id, I18n.t('front_page_lock.upcoming_event_required'))
    end
  end

  def to_param
    position
  end
end

# == Schema Information
#
# Table name: front_page_locks
#
#  id         :integer          not null, primary key
#  event_id   :integer
#  created_at :datetime         not null
#  updated_at :datetime         not null
#  position   :integer
#
